#!/usr/bin/env python

"""
Welcome layout
v2

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="Welcome!" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 ga=h gd=s gi=5;', echo=True)
    
    #Text
    et.transceive('dt x=160 y=50 a=c t="Hello there! Thank you for your interest in EasyTerm!\\nYou can adjust LCD brightness via slider.\\nYou can also show system info using button.\\nFinally you can erase this layout to get space\\nfor your very own layout!";', echo=True)
    et.transceive('dg x=30 y=130 w=260 c=100,100,100 h=1;', echo=True)
    
    #Slider
    et.transceive('dt x=160 a=c y=164 t="- Set LCD brightness via slider -";', echo=True)
    et.transceive('ds x=4 y=180 w=312 h=40 v=50 a="SYS b=%d+Brightness set to:%d";', echo=True)
    
    #Buttons
    et.transceive('db x=4 y=258 w=312 h=40 t="Sleep EasyTerm to conserve power (awake by touch)" a="SYS sl=0+SYS sleep";', echo=True)
    et.transceive('db x=4 y=300 w=155 h=40 t="Show system info in log" a="SYS info=?";', echo=True)
    et.transceive('db x=161 y=300 w=155 h=40 t="Erase this layout" a="csp+sl bid=0+sys coi=\\"\\"";', echo=True)
    
    et.transceive('dl y=350 h=130;', echo=True)

    #Uncomment to save layout in flash and recover after device startup
    et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
